# Tips and tricks when using patterns

## You can disable patterns by changing the URL

When working with patterns, it might be useful to selectively disable
certain patterns.

You can easily do this by adding the `patterns-disable` parameter to the query string
of the URL you are on.

For example, if you'd like to disable the `toggle` pattern, then add
`?patterns-disable=toggle` to your URLs query string.
